@@ -133,10 +133,11 @@ cx      DIMENSION  PARAM(*)
 cxx      DIMENSION  PARAM(1)
       REAL(8) :: X, PARAM(1), dgammafn
 C
+      CHISQR = 0.0D0
       IF( X.GT.0.0D0 ) CHISQR = DEXP( -X/2 )*(X/2)**(PARAM(1)/2-1.D0)
 CXX     *                           /(2*DGAMMA(PARAM(1)/2))
      *                           /(2*dgammafn(PARAM(1)/2))
-      IF( X.LE.0.0D0 ) CHISQR = 0.0D0
+cxx      IF( X.LE.0.0D0 ) CHISQR = 0.0D0
       RETURN
       E N D
       DOUBLE PRECISION FUNCTION  UNIFRM( X,PARAM )
